@@ -1,7 +1,7 @@
 use crate::errors::*;
 use crate::patterns::Pattern;
 use crate::schedule::PreferedHours;
-use human_size::{Size, SpecificSize};
+use human_size::{Byte, Size, SpecificSize};
 use serde::{de, Deserialize, Deserializer};
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
@@ -17,6 +17,8 @@ pub struct Config {
 
 #[derive(Debug, Default, Deserialize)]
 pub struct ScanConfig {
+    #[serde(default)]
+    pub paths: Vec<PathBuf>,
     #[serde(default)]
     pub excludes: Vec<Pattern>,
     #[serde(default)]
@@ -65,9 +67,8 @@ pub fn load() -> Result<Config> {
 #[derive(Debug)]
 pub struct HumanSize(SpecificSize);
 
-use human_size::Byte;
-
 impl HumanSize {
+    #[must_use]
     pub fn as_bytes(&self) -> u64 {
         self.0.into::<Byte>().value() as u64
     }
