@@ -32,10 +32,10 @@ fn is_hidden(entry: &DirEntry) -> bool {
     entry
         .file_name()
         .to_str()
-        .map(|s| s.starts_with('.'))
-        .unwrap_or(false)
+        .map_or(false, |s| s.starts_with('.'))
 }
 
+#[must_use]
 pub fn matches(config: &ScanConfig, e: &DirEntry) -> bool {
     let path = e.path();
 
@@ -74,10 +74,17 @@ pub fn matches(config: &ScanConfig, e: &DirEntry) -> bool {
     true
 }
 
-pub fn ingest_directory(cfg: &ScanConfig, tx: &Sender<DirEntry>, path: &Path) -> Result<()> {
+pub fn ingest_directory(cfg: &ScanConfig, tx: &Sender<DirEntry>, path: &Path) {
     let walker = WalkDir::new(path).into_iter();
     for entry in walker.filter_entry(|e| matches(cfg, e)) {
-        let entry = entry?;
+        let entry = match entry {
+            Ok(entry) => entry,
+            Err(err) => {
+                warn!("Failed to scan directory: {:#}", err);
+                continue;
+            }
+        };
+
         let path = entry.path();
         let ft = entry.file_type();
 
@@ -97,8 +104,6 @@ pub fn ingest_directory(cfg: &ScanConfig, tx: &Sender<DirEntry>, path: &Path) ->
             break;
         }
     }
-
-    Ok(())
 }
 
 pub struct Scanner {
@@ -118,7 +123,8 @@ impl Scanner {
             .map_err(|e| anyhow!("Failed to load clamav database: {:#}", e))?;
 
         info!("Checking database age...");
-        let daily_path = path.join("daily.cld");
+        let daily_path = Self::find_daily_db_path(path)?;
+
         let mut buf = [0; 512];
         read_clamav_header(&daily_path, &mut buf)?;
         let signatures_age = parse_database_age(&buf)?;
@@ -135,10 +141,24 @@ impl Scanner {
         })
     }
 
+    fn find_daily_db_path(base_dir: &Path) -> Result<PathBuf> {
+        for filename in &["daily.cld", "daily.cvd"] {
+            let daily_path = base_dir.join(filename);
+            debug!("Checking if database exists: {:?}", daily_path);
+            if daily_path.exists() {
+                return Ok(daily_path);
+            }
+        }
+
+        bail!("Couldn't find clamav database file");
+    }
+
+    #[must_use]
     pub fn signature_count(&self) -> usize {
         self.signature_count as usize
     }
 
+    #[must_use]
     pub fn signatures_age(&self) -> DateTime<Utc> {
         self.signatures_age
     }
@@ -151,31 +171,38 @@ impl Scanner {
         let hit = self
             .engine
             .scan_file(&path_str, &mut settings)
-            .map_err(|e| anyhow!("Failed to scan file: {:#}", e))?;
+            .map_err(|e| anyhow!("Failed to scan file {:?}: {:#}", path, e))?;
 
         match hit {
             ScanResult::Virus(name) => {
                 warn!("Found threat: {} ({:?})", path.display(), name);
                 results_tx.send((path.to_path_buf(), name)).ok();
             }
-            ScanResult::Clean => (),
-            ScanResult::Whitelisted => (),
+            ScanResult::Clean | ScanResult::Whitelisted => (),
         }
 
+        debug!("Finished scanning file {}", path.display());
+
         Ok(())
     }
 }
 
-pub fn run(mut args: args::Scan) -> Result<()> {
+pub fn run(args: args::Scan) -> Result<()> {
     let config = config::load().context("Failed to load config")?;
 
     let mut db = Database::load().context("Failed to load database")?;
 
-    if args.paths.is_empty() {
-        info!("Empty arguments, defaulting to home directory");
+    let paths = if !args.paths.is_empty() {
+        info!("Scanning provided paths: {:?}", args.paths);
+        args.paths
+    } else if !config.scan.paths.is_empty() {
+        info!("Scanning configured paths: {:?}", config.scan.paths);
+        config.scan.paths.clone()
+    } else {
         let home_dir = dirs::home_dir().context("Failed to find home directory")?;
-        args.paths.push(home_dir);
-    }
+        info!("Scanning home directory: {:?}", home_dir);
+        vec![home_dir]
+    };
 
     let data = db.data_mut();
     data.threats.clear();
@@ -195,7 +222,7 @@ pub fn run(mut args: args::Scan) -> Result<()> {
         thread::spawn(move || {
             for entry in fs_rx {
                 if let Err(err) = scanner.scan_file(entry.path(), &results_tx) {
-                    error!("Failed to scan file: {:#}", err);
+                    error!("{:#}", err);
                 }
             }
             mem::drop(results_tx);
@@ -204,11 +231,9 @@ pub fn run(mut args: args::Scan) -> Result<()> {
     mem::drop(results_tx);
 
     thread::spawn(move || {
-        for path in args.paths {
+        for path in paths {
             info!("Scanning directory {}...", path.display());
-            if let Err(err) = ingest_directory(&config.scan, &fs_tx, &path) {
-                error!("Failed to scan directory: {:#}", err);
-            }
+            ingest_directory(&config.scan, &fs_tx, &path);
         }
         debug!("Finished traversing directories");
     });
@@ -231,7 +256,8 @@ pub fn read_clamav_header(path: &Path, buf: &mut [u8]) -> Result<()> {
         bail!("Buffer has wrong size");
     }
 
-    let mut f = File::open(path).context("Failed to open clamav database")?;
+    let mut f =
+        File::open(path).with_context(|| anyhow!("Failed to open clamav database: {:?}", path))?;
     f.read_exact(buf)
         .context("Failed to read header from clamav database")?;
 
